Skip to main content Crate edge_nal_embassy Copy item path Source Dns A type that implements the Dns trait from edge-nal.
It uses the DNS resolver from the provided Embassy networking stack. DnsError DNS error type Pool A simple fixed-size pool allocator for T. Tcp A type that implements the TcpConnect and TcpBind factory traits from edge-nal
Uses the provided Embassy networking stack and TCP buffers pool to create TCP sockets. TcpAccept A type that represents an acceptor for incoming TCP client connections.
Implements the TcpAccept factory trait from edge-nal TcpSocket A type that represents a TCP socket
Implements the Read and Write traits from embedded-io-async, as well as the TcpSplit factory trait from edge-nal TcpSocketBuffers A type that holds the TCP socket buffers. TcpSocketRead A type that represents the read half of a split TCP socket.
Implements the Read trait from embedded-io-async. TcpSocketWrite A type that represents the write half of a split TCP socket.
Implements the Write trait from embedded-io-async. Udp A type that implements the UdpBind factory trait from edge-nal.
Uses the provided Embassy networking stack and UDP buffers pool to create UDP sockets. UdpSocket A UDP socket.
Implements the UdpReceive UdpSend and UdpSplit traits from edge-nal. UdpSocketBuffers A type that holds the UDP socket buffers. TcpError A shared error type that is used by the TCP factory traits implementation as well as the TCP socket. UdpError A shared error type that is used by the UDP factory trait implementation as well as the UDP socket DynPool A const-generics-erased trait variant of Pool TcpBuffers A type alias for a pool of TCP socket buffers. UdpBuffers A type alias for a pool of UDP socket buffers.